/*
 仓库表
 */
CREATE TABLE IF NOT EXISTS "repository" (
  "id" INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
  "name" TEXT,
  "create_time" TIMESTAMP NOT NULL DEFAULT (datetime('now','localtime')),
  "update_time" TIMESTAMP NOT NULL DEFAULT (datetime('now','localtime'))
);

/*
 页面表
 */
CREATE TABLE IF NOT EXISTS "page" (
  "id" INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
  "repo_id" INTEGER NOT NULL,
  "page_url" TEXT,
  "page_title" TEXT,
  "page_logo_path" TEXT,
  "page_screenshot_path" TEXT,
  "checkpoint_count" INTEGER,
  "analysis_count" INTEGER,
  "begin_time" INTEGER,
  "end_time" INTEGER,
  "page_load_time" INTEGER,
  "create_time" TIMESTAMP NOT NULL DEFAULT (datetime('now','localtime')),
  "update_time" TIMESTAMP NOT NULL DEFAULT (datetime('now','localtime'))
);

/*
 页面规则记录表
 */
CREATE TABLE IF NOT EXISTS "page_rule_record" (
  "id" INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
  "page_id" INTEGER NOT NULL,
  "repo_id" INTEGER NOT NULL,
  "knowledge_id" INTEGER NOT NULL,
  "create_time" TIMESTAMP NOT NULL DEFAULT (datetime('now','localtime')),
  "update_time" TIMESTAMP NOT NULL DEFAULT (datetime('now','localtime'))
);

/*
 页面规则配置表
 */
CREATE TABLE IF NOT EXISTS "page_rule_config" (
  "id" INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
  "page_id" INTEGER NOT NULL,
  "repo_id" INTEGER NOT NULL,
  "knowledge_id" INTEGER NOT NULL,
  "create_time" TIMESTAMP NOT NULL DEFAULT (datetime('now','localtime')),
  "update_time" TIMESTAMP NOT NULL DEFAULT (datetime('now','localtime'))
);

/*
 页面分析记录详情表
 */
CREATE TABLE IF NOT EXISTS "page_analysis_record_detail" (
  "id" INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
  "page_id" INTEGER NOT NULL,
  "repo_id" INTEGER NOT NULL,
  "page_url" TEXT,
  "knowledge_id" INTEGER NOT NULL,
  "count" INTEGER NOT NULL,
  "solution_id" INTEGER,
  "create_time" TIMESTAMP NOT NULL DEFAULT (datetime('now','localtime')),
  "update_time" TIMESTAMP NOT NULL DEFAULT (datetime('now','localtime'))
);

/*
 页面记录资源文件关联表
 */
CREATE TABLE IF NOT EXISTS "page_record_file_associate" (
  "id" INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
  "repo_id" INTEGER NOT NULL,
  "page_id" INTEGER NOT NULL,
  "knowledge_id" INTEGER NOT NULL,
  "resource_file_id" INTEGER NOT NULL,
  "create_time" TIMESTAMP NOT NULL DEFAULT (datetime('now','localtime')),
  "update_time" TIMESTAMP NOT NULL DEFAULT (datetime('now','localtime'))
);

/*
 页面资源文件表
 */
CREATE TABLE IF NOT EXISTS "page_resource_file" (
  "id" INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
  "repo_id" INTEGER NOT NULL,
  "page_id" INTEGER NOT NULL,
  "knowledge_id" INTEGER NOT NULL,
  "file_type" INTEGER NOT NULL,
  "file_name" TEXT,
  "file_url" TEXT,
  "position" TEXT,
  "original_file_path" TEXT,
  "original_file_url" TEXT,
  "anchor_point_file_path" TEXT,
  "create_time" TIMESTAMP NOT NULL DEFAULT (datetime('now','localtime')),
  "update_time" TIMESTAMP NOT NULL DEFAULT (datetime('now','localtime'))
);

/*
 修复记录表
 */
CREATE TABLE IF NOT EXISTS "page_fix_record" (
  "id" INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
  "page_id" INTEGER NOT NULL,
  "repo_id" INTEGER NOT NULL,
  "knowledge_id" INTEGER NOT NULL,
  "resource_file_id" INTEGER NOT NULL,
  "fix_type" INTEGER NOT NULL,
  "solution_id" INTEGER NOT NULL,
  "create_time" TIMESTAMP NOT NULL DEFAULT (datetime('now','localtime')),
  "update_time" TIMESTAMP NOT NULL DEFAULT (datetime('now','localtime'))
);

/*
 自定义知识库表
 */
--CREATE TABLE IF NOT EXISTS "custom_knowledge" (
--  "id" integer NOT NULL,
--  "number" text(32) NOT NULL,
--  "title" text(100) NOT NULL,
--  "repo_id"   INTEGER NOT NULL,
--  "page_id"   INTEGER NOT NULL,
--  "url"	TEXT,
--  "author" text(45),
--  "type" integer(11) NOT NULL,
--  "origin" integer(11) NOT NULL,
--  "level" integer(11) NOT NULL,
--  "solution" text(300),
--  "w3help_url" text(100),
--  "new_url" text(100),
--  "create_time" TIMESTAMP NOT NULL DEFAULT (datetime('now','localtime')),
--  "update_time" TIMESTAMP NOT NULL DEFAULT (datetime('now','localtime'))
--);

/*
 自定义补丁表
 */
--CREATE TABLE IF NOT EXISTS "custom_patch" (
--  "id" integer NOT NULL,
--  "zsk_number" text(32) NOT NULL,
--  "title" text(100),
--  "repo_id"   INTEGER NOT NULL,
--  "page_id"   INTEGER NOT NULL,
--  "url"	TEXT,
--  "author" text(45),
--  "recommend" integer(11) NOT NULL,
--  "code" text,
--  "create_time" TIMESTAMP NOT NULL DEFAULT (datetime('now','localtime')),
--  "update_time" TIMESTAMP NOT NULL DEFAULT (datetime('now','localtime'))
--);


/*
 自定义规则表
 */
--CREATE TABLE IF NOT EXISTS "custom_rule_code" (
--  "id" integer NOT NULL PRIMARY KEY AUTOINCREMENT,
--  "zsk_number" text (32) NOT NULL,
--  "type" integer (11),
--  "title" text (100),
--  "author" text (45),
--  "code" text,
--  "create_time" text (3),
--  "update_time" text (3)
--);

/*
 站点过滤列表（黑名单、白名单）
 */
CREATE TABLE IF NOT EXISTS "knowledge_version" (
	"id"	INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
	"version"	int NOT NULL,
	"address"	TEXT,
	"desc"	TEXT,
	"enable"	int default 0,
	"type"	int default 0,
	"create_time" TIMESTAMP NOT NULL DEFAULT (datetime('now','localtime'))
);

/*
 激活信息表
 */
CREATE TABLE IF NOT EXISTS "license" (
	"id"    INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
	"activate_type"	INTEGER,
	"kms_ip"	TEXT,
	"kms_port"	TEXT,
	"activate_key"	TEXT,
	"custom_id"	TEXT,
	"authorized_type"   INTEGER,
	"product_version"	TEXT,
	"valid_end_time" TIMESTAMP NOT NULL DEFAULT (datetime('now','localtime')),
  "create_time" TIMESTAMP NOT NULL DEFAULT (datetime('now','localtime')),
  "update_time" TIMESTAMP NOT NULL DEFAULT (datetime('now','localtime'))
);